@@ -23,6 +23,7 @@ import files_sdk.models.bundle_notification as bundle_notification
 import files_sdk.models.bundle_path as bundle_path
 import files_sdk.models.bundle_recipient as bundle_recipient
 import files_sdk.models.bundle_registration as bundle_registration
+import files_sdk.models.child_site_management_policy as child_site_management_policy
 import files_sdk.models.clickwrap as clickwrap
 import files_sdk.models.dns_record as dns_record
 import files_sdk.models.email_incoming_message as email_incoming_message
@@ -131,6 +132,9 @@ from files_sdk.models.bundle_notification import BundleNotification
 from files_sdk.models.bundle_path import BundlePath
 from files_sdk.models.bundle_recipient import BundleRecipient
 from files_sdk.models.bundle_registration import BundleRegistration
+from files_sdk.models.child_site_management_policy import (
+    ChildSiteManagementPolicy,
+)
 from files_sdk.models.clickwrap import Clickwrap
 from files_sdk.models.dns_record import DnsRecord
 from files_sdk.models.email_incoming_message import EmailIncomingMessage
@@ -223,7 +227,7 @@ session_id = None
 source_ip = None
 base_url = "https://app.files.com"
 base_path = "api/rest/v1"
-version = "1.6.47"
+version = "1.6.58"
 
 __version__ = version
 
