@@ -1342,6 +1342,36 @@ class InsufficientPermissionForSiteError(NotAuthorizedError):
         )
 
 
+class MoverAccessDeniedError(NotAuthorizedError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
+class MoverPackageRequiredError(NotAuthorizedError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class MustAuthenticateWithApiKeyError(NotAuthorizedError):
     def __init__(
         self,
@@ -1402,6 +1432,21 @@ class NotAllowedToCreateBundleError(NotAuthorizedError):
         )
 
 
+class NotEnqueuableSyncError(NotAuthorizedError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class PasswordChangeNotRequiredError(NotAuthorizedError):
     def __init__(
         self,
@@ -1432,6 +1477,21 @@ class PasswordChangeRequiredError(NotAuthorizedError):
         )
 
 
+class PaymentMethodErrorError(NotAuthorizedError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class ReadOnlySessionError(NotAuthorizedError):
     def __init__(
         self,
@@ -1837,6 +1897,21 @@ class ProcessingFailureError(APIError):
         )
 
 
+class AgentUnavailableError(ProcessingFailureError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class AlreadyCompletedError(ProcessingFailureError):
     def __init__(
         self,
@@ -2452,6 +2527,21 @@ class SubfolderLockedError(ProcessingFailureError):
         )
 
 
+class SyncInProgressError(ProcessingFailureError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class TwoFactorAuthenticationCodeAlreadySentError(ProcessingFailureError):
     def __init__(
         self,
@@ -2681,21 +2771,6 @@ class ServiceUnavailableError(APIError):
         )
 
 
-class AgentUnavailableError(ServiceUnavailableError):
-    def __init__(
-        self,
-        message=None,
-        http_body=None,
-        http_status=None,
-        json_body=None,
-        headers=None,
-        code=None,
-    ):
-        super().__init__(
-            message, http_body, http_status, json_body, headers, code
-        )
-
-
 class AutomationsUnavailableError(ServiceUnavailableError):
     def __init__(
         self,
